@@ -1,6 +1,6 @@
 // Display a reconciled tree form recPhyloXML format
 
-use light_phylogeny::{ArenaTree,Options,Config,read_recphyloxml,recphyloxml_processing};
+use light_phylogeny::{ArenaTree,Options,Config,read_recphyloxml_multi,recphyloxml_processing};
 
 fn main() {
 
@@ -10,8 +10,9 @@ fn main() {
     // Version portrait
     let mut sp_tree: ArenaTree<String> = ArenaTree::default();
     let mut gene_trees:std::vec::Vec<ArenaTree<String>> = Vec::new();
-    read_recphyloxml("examples/FAM000715_reconciliated_2genes.recphylo".to_string(),
-        &mut sp_tree, &mut gene_trees);
+    let mut global_roots: std::vec::Vec<usize> = Vec::new();
+    read_recphyloxml_multi("examples/FAM000715_reconciliated_2genes.recphylo".to_string(),
+        &mut sp_tree, &mut gene_trees, &mut global_roots);
     recphyloxml_processing(&mut sp_tree, &mut gene_trees, &mut options, &config, true,
          &transfers, "read_recphyloxml_portrait.svg".to_string());
     println!("Please open output file 'read_recphyloxml_portrait.svg' with your browser");
@@ -19,8 +20,9 @@ fn main() {
     // Version paysage
     let mut sp_tree: ArenaTree<String> = ArenaTree::default();
     let mut gene_trees:std::vec::Vec<ArenaTree<String>> = Vec::new();
-    read_recphyloxml("examples/FAM000715_reconciliated_2genes.recphylo".to_string(),
-        &mut sp_tree, &mut gene_trees);
+    let mut global_roots: std::vec::Vec<usize> = Vec::new();
+    read_recphyloxml_multi("examples/FAM000715_reconciliated_2genes.recphylo".to_string(),
+        &mut sp_tree, &mut gene_trees, &mut global_roots);
     options.rotate = false;
     config.species_opacity = "0.3".to_string();
     config.gene_opacity = "0.6".to_string();
@@ -35,8 +37,9 @@ fn main() {
 
     let mut sp_tree: ArenaTree<String> = ArenaTree::default();
     let mut gene_trees:std::vec::Vec<ArenaTree<String>> = Vec::new();
-    read_recphyloxml("examples/test_5genes.recphylo".to_string(),
-        &mut sp_tree, &mut gene_trees);
+    let mut global_roots: std::vec::Vec<usize> = Vec::new();
+    read_recphyloxml_multi("examples/test_5genes.recphylo".to_string(),
+        &mut sp_tree, &mut gene_trees, &mut global_roots);
     recphyloxml_processing(&mut sp_tree, &mut gene_trees, &mut options, &config, true,
          &transfers, "read_recphyloxml_mult.svg".to_string());
     println!("Please open output file 'read_recphyloxml_mult.svg' with your browser");
@@ -48,8 +51,9 @@ fn main() {
 
     let mut sp_tree: ArenaTree<String> = ArenaTree::default();
     let mut gene_trees:std::vec::Vec<ArenaTree<String>> = Vec::new();
-    read_recphyloxml("examples/FAM000297_reconciliated.recphylo".to_string(),
-        &mut sp_tree, &mut gene_trees);
+    let mut global_roots: std::vec::Vec<usize> = Vec::new();
+    read_recphyloxml_multi("examples/FAM000297_reconciliated.recphylo".to_string(),
+        &mut sp_tree, &mut gene_trees, &mut global_roots);
     recphyloxml_processing(&mut sp_tree, &mut gene_trees, &mut options, &config, true,
          &transfers, "read_recphyloxml_FAM000297_reconciliated.svg".to_string());
     println!("Please open output file 'read_recphyloxml_FAM000297_reconciliated' with your browser");
