@@ -141,7 +141,8 @@ where
 }
 impl<T> ArenaTree<T>
 where
-    T: PartialEq
+    T: PartialEq + std::default::Default
+
 {
     #[allow(dead_code)]
     /// Add a node and send its new index. If the
@@ -265,6 +266,48 @@ where
             }
         min
     }
+    /// Copy
+    pub fn copie(&mut self) -> ArenaTree<String> {
+        let  mut new: ArenaTree<String> = ArenaTree::default();
+        let mut i = 0;
+        for node in &self.arena {
+            let  idx = new.new_node(i.to_string());
+            new.arena[idx].name = node.name.clone();
+            new.arena[idx].support = node.support.clone();
+            new.arena[idx].parent = node.parent;
+            new.arena[idx].children = node.children.clone();
+            new.arena[idx].x = node.x;
+            new.arena[idx].y = node.y;
+            new.arena[idx].xmod = node.xmod;
+            new.arena[idx].ymod = node.ymod;
+            new.arena[idx].l = node.l;
+            new.arena[idx].e = match node.e {
+                Event::Speciation => Event::Speciation,
+                Event::Duplication => Event::Duplication,
+                Event::Loss => Event::Loss,
+                Event::BranchingOut => Event::BranchingOut,
+                Event::TransferBack => Event::TransferBack,
+                Event::BifurcationOut => Event::BifurcationOut,
+                Event::Leaf => Event::Leaf,
+                Event::ObsoleteSpeciationLoss => Event::ObsoleteSpeciationLoss,
+                Event::Undef => Event::Undef,
+            };
+            new.arena[idx].location = node.location.clone();
+            new.arena[idx].width = node.width;
+            new.arena[idx].height = node.height;
+            new.arena[idx].nbg = node.nbg;
+            new.arena[idx].nodes = node.nodes.clone();
+            new.arena[idx].is_a_transfert = node.is_a_transfert;
+            new.arena[idx].go_left = node.go_left;
+            new.arena[idx].go_right = node.go_right;
+            new.arena[idx].fixed = node.fixed;
+            new.arena[idx].transfers = node.transfers.clone();
+            new.arena[idx].visible = node.visible;
+
+            i = i + 1 ;
+            }
+        new
+    }
 }
 
 ///  Structure Options: drawing options.
@@ -310,6 +353,8 @@ pub struct Options{
     pub width:f32,
     /// display support
     pub support:bool,
+    /// free free_living
+    pub free_living:bool,
 }
 impl Options {
     pub fn new() -> Self {
@@ -334,6 +379,7 @@ impl Options {
             height:1.0,
             width:1.0,
             support:false,
+            free_living:false,
 
         }
     }
@@ -993,7 +1039,11 @@ pub fn map_species_trees(sp_tree: &mut ArenaTree<String>,
                 }
             }
             if !mapped {
-                panic!("Unable to map Node {:?}",index);
+
+                eprintln!("\nERROR: Unable to map Node {:?}",index);
+                eprintln!("\nThe species '{}' was not found in species tree", index.location);
+                eprintln!("\nMaybe you should use the 'free_living' option.");
+                process::exit(1)
             }
         }
         // Passe à l'arbre de gènes suivant
@@ -1260,6 +1310,53 @@ pub fn move_species_mappings(sp_tree: &mut ArenaTree<String>,
     }
 }
 
+
+// Move species father when necessary in free living tree
+pub fn move_species_mappings_fl(sp_tree: &mut ArenaTree<String>,
+                           gene_trees: &mut std::vec::Vec<ArenaTree<String>>, index: usize) {
+                               // let mut nodes = &mut sp_tree.arena[index].nodes;
+                               // nodes.reverse();
+    info!("[move_species_mappings_fl] Processing {}",index);
+    //  Recupere les feuilles des arbres de gene
+    let mut  genes = vec![];
+    let mut  feuilles = vec![];
+    for (index_node, node) in &sp_tree.arena[index].nodes {
+        info!("[move_species_mappings_fl] >>> {:?} {:?}",gene_trees[*index_node].arena[*node].name,
+         gene_trees[*index_node].arena[*node].e);
+        if gene_trees[*index_node].arena[*node].e == Event::Leaf {
+            if !genes.contains(index_node) {
+                genes.push(*index_node);
+                feuilles.push((index_node,node));
+            }
+        };
+
+    }
+    //  recherche parent
+    for (index_node, node) in feuilles {
+        let mut _parent = *node;
+        let mut parent = gene_trees[*index_node].arena[*node].parent.expect("[move_species_mappings_fl] ERROR Unexpected root");
+            info!("[move_species_mappings_fl] {} {} {:?}",index_node,node,parent);
+
+            while gene_trees[*index_node].arena[*node].location == gene_trees[*index_node].arena[parent].location
+             {
+                 _parent = parent;
+                 parent = gene_trees[*index_node].arena[parent].parent.expect("[move_species_mappings] ERROR Unexpected root");
+                 info!("[move_species_mappings_fl] {} {} {:?}",index_node,node,parent);
+             }
+        info!("[move_species_mappings_fl] Ancestor of the gene {} in this species node is {:?}",index_node,gene_trees[*index_node].arena[parent]);
+        set_middle_postorder(&mut gene_trees[*index_node], _parent);
+
+    }
+    // Normalement cette etape n'est pas necessaire:
+    let children =  &mut  sp_tree.arena[index].children;
+    if children.len() > 0 {
+        let son_left = children[0];
+        let son_right = children[1];
+        move_species_mappings_fl( sp_tree, gene_trees,son_left);
+        move_species_mappings_fl( sp_tree, gene_trees,son_right);
+    }
+}
+
 // Center the gene nodes into a  specie snode
 pub fn center_gene_nodes(sp_tree: &mut ArenaTree<String>,
                          gene_trees: &mut std::vec::Vec<ArenaTree<String>>, index: usize) {
