@@ -11,7 +11,7 @@ use crate::arena::{newick2tree,xml2tree};
 use crate::arena::{knuth_layout,cladogramme,check_contour_postorder,shift_mod_xy,
     set_middle_postorder,real_length,set_leaves_y_values};
 use crate::arena::{map_species_trees,set_species_width,check_vertical_contour_postorder,
-    bilan_mappings,center_gene_nodes,move_dupli_mappings,move_species_mappings};
+    bilan_mappings,center_gene_nodes,move_dupli_mappings,move_species_mappings,move_species_mappings_fl};
 use crate::arena::{find_sptrees,find_rgtrees,check_for_obsolete,scale_heigth,scale_width};
 use crate::thirdlevel::{get_gtransfer,optimisation,check_optimisation,classify_transfer,reorder_transfers};
 use crate::drawing::{draw_tree,draw_sptree_gntrees};
@@ -406,6 +406,24 @@ pub fn recphyloxml_processing(
 // Au depart l'arbre est orienté du haut vers le bas (i.e. selon Y)
 // Le svg sera tourné de -90 a la fin.
 //
+
+//  Option : ajout d'une branche free_living
+
+let initial_root = sp_tree.get_root();
+let mut free_root = 0;
+if options.free_living {
+    let left = sp_tree.get_root();
+    let  right = sp_tree.new_node("free_living".to_string());
+    sp_tree.arena[right].name="FREE_LIVING".to_string();
+    free_root = right;
+    let  fl_root = sp_tree.new_node("free_living_root".to_string());
+    sp_tree.arena[fl_root].name="FREE_LIVING_ROOT".to_string();
+    sp_tree.arena[fl_root].visible=false;
+    sp_tree.arena[fl_root].children.push(left);
+    sp_tree.arena[fl_root].children.push(right);
+    sp_tree.arena[right].parent=Some(fl_root);
+    sp_tree.arena[left].parent=Some(fl_root);
+}
 //----------------------------------------------------------
 // 1ere étape :initialisation des x,y de l'arbre d'espèces :
 // profondeur => Y, left => X= 0, right X=1
@@ -531,19 +549,25 @@ bilan_mappings(&mut sp_tree, &mut gene_trees,root, & options);
 // ---------------------------------------------------------
 // 11eme etape : centre les noeuds de genes dans le noeud de l'espece
 // ---------------------------------------------------------
-center_gene_nodes(&mut sp_tree,&mut gene_trees,root);
+center_gene_nodes(&mut sp_tree,&mut gene_trees,initial_root);
 // ---------------------------------------------------------
 // 12eme etape traite spécifiquement les duplications et les feuilles
 // ---------------------------------------------------------
-move_dupli_mappings(&mut sp_tree, &mut gene_trees,root);
+move_dupli_mappings(&mut sp_tree, &mut gene_trees,initial_root);
 
 // 13eme etape : Ca des speciations dont les fils sont
 // dans le meme noeud "tuyeau" que le pere
 // Cela n'arrice que quand on mappe des genes sur des hotes
 // via les parasites (thirdlevel)
-
 // ---------------------------------------------------------
-move_species_mappings(&mut sp_tree, &mut gene_trees,root);
+move_species_mappings(&mut sp_tree, &mut gene_trees,initial_root);
+
+if options.free_living {
+    center_gene_nodes(&mut sp_tree,&mut gene_trees,free_root);
+    move_dupli_mappings(&mut sp_tree, &mut gene_trees,free_root);
+    move_species_mappings_fl(&mut sp_tree, &mut gene_trees,free_root);
+
+}
 // // ---------------------------------------------------------
 // // Fin: Ecriture du fichier svg
 // // ---------------------------------------------------------
